from math import gcd
from itertools import combinations
from fractions import Fraction

class Point:
    def __init__(self, x, y):
        self.x = x
        self.y = y
    def __str__(self):
        return "x: " + str(self.x) + "; y: " + str(self.y)
    def __ne__(self, other):
        return self.x != other.x or self.y != other.y
    def __eq__(self, other):
        return self.x == other.x and self.y == other.y
    def __ge__(self, other):
        return self.x > other.x or (self.x == other.x and self.y >= other.y)

def lines_from_points(pt1, pt2):
    A = pt1.y - pt2.y
    B = pt2.x - pt1.x
    C = pt1.x*pt2.y - pt2.x*pt1.y
    d = gcd(A, B)
    d = gcd(d, C)
    return (A // d, B // d, C // d)

def det(a, b, c, d):
    return a*d - b*c

def between(left, right, pt):
    return min(left.x, right.x) <= pt.x and pt.x <= max(left.x, right.x) \
        and min(left.y, right.y) <= pt.y and pt.y <= max(left.y, right.y)

def merge_points(pt1_left, pt1_right, pt2_left, pt2_right):
    if pt1_left >= pt1_right:
        pt1_left, pt1_right = pt1_right, pt1_left
    if pt2_left >= pt2_right:
        pt2_left, pt2_right = pt2_right, pt2_left
    if pt1_right == pt2_left:
        return (Point(pt1_left.x, pt1_left.y), Point(pt2_right.x, pt2_right.y))
    elif pt2_right == pt1_left:
        return (Point(pt2_left.x, pt2_left.y), Point(pt1_right.x, pt1_right.y))
    else:
        return (Point(pt1_left.x, pt1_left.y), Point(pt1_right.x, pt1_right.y))
    

def intersection(pt1_left, pt1_right, pt2_left, pt2_right, line1, line2):
    A1, B1, C1 = line1
    A2, B2, C2 = line2
    denom = det(A1, B1, A2, B2)
    if denom == 0:
        return None
    x = Fraction(-1*det(C1, B1, C2, B2), denom)
    y = Fraction(-1*det(A1, C1, A2, C2), denom)
    pt = Point(x, y)
    return pt if between(pt1_left, pt1_right, pt) \
        and between(pt2_left, pt2_right, pt) else None

def lines_equal(line1, line2):
    return line1 == line2 or \
        (line1[0] == -line2[0] 
            and line1[1] == -line2[1] 
            and line1[2] == -line2[2])

def merge_lines(lines, points):
    n = len(lines)
    for i in range(n):
        for j in range(i + 1, n):
            if lines_equal(lines[i], lines[j]):
                merged = merge_points(*points[i], *points[j])
                if merged != points[i]:
                    points[i] = merged
                    del points[j]
                    del lines[j]
                    return True
    return False
                

n = int(input())
input_points = list()
lines = list()
read = 0
while read < n:
    input_str = ""
    while len(input_str.split(' ')) != 4:
        input_str = input()
    
    read += 1
    coords = list(map(int, input_str.split(' ')))
    pt1 = Point(coords[0], coords[1])
    pt2 = Point(coords[2], coords[3])
    line = lines_from_points(pt1, pt2)
    lines.append(line)
    input_points.append((pt1, pt2))
    while (merge_lines(lines, input_points) == True):
        pass

ans = 0
for indices in combinations(range(0, len(lines)), 3):
    i, j, k = indices
    intersect12 = intersection(input_points[i][0], input_points[i][1], 
        input_points[j][0], input_points[j][1], lines[i], lines[j])
    intersect23 = intersection(input_points[j][0], input_points[j][1], 
        input_points[k][0], input_points[k][1], lines[j], lines[k])
    intersect13 = intersection(input_points[i][0], input_points[i][1], 
        input_points[k][0], input_points[k][1], lines[i], lines[k])
    if intersect12 and intersect23 and intersect13 and intersect12 != intersect23:
        ans += 1

print(ans)
